
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>
#include <gmodule.h>

G_BEGIN_DECLS

/* enumerations from "gfls-error.h" */

G_MODULE_EXPORT
GType gfls_loader_error_get_type (void);
#define GFLS_TYPE_LOADER_ERROR (gfls_loader_error_get_type())

/* enumerations from "gfls-iconv.h" */

G_MODULE_EXPORT
GType gfls_iconv_result_get_type (void);
#define GFLS_TYPE_ICONV_RESULT (gfls_iconv_result_get_type())

G_END_DECLS

/* Generated data ends here */

